package com.huiju.estateagents.redpack.controller;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.redpack.entity.TaOrgAccountBlocked;
import com.huiju.estateagents.redpack.service.ITaOrgAccountBlockedService;

/**
 * <p>
    * 账户冻结记录  前端控制器
    * </p>
 *
 * @author fxf
 * @since 2020-06-03
 */
@RestController
@RequestMapping("/")
public class TaOrgAccountBlockedController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaOrgAccountBlockedController.class);

    @Autowired
    public ITaOrgAccountBlockedService iTaOrgAccountBlockedService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taOrgAccountBlocked",method= RequestMethod.GET)
    public ResponseBean taOrgAccountBlockedList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                                @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaOrgAccountBlocked> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaOrgAccountBlocked> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaOrgAccountBlocked> result = iTaOrgAccountBlockedService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taOrgAccountBlockedList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taOrgAccountBlocked 实体对象
     * @return
     */
    @RequestMapping(value="/taOrgAccountBlocked",method= RequestMethod.POST)
    public ResponseBean taOrgAccountBlockedAdd(@RequestBody TaOrgAccountBlocked taOrgAccountBlocked){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaOrgAccountBlockedService.save(taOrgAccountBlocked)){
                responseBean.addSuccess(taOrgAccountBlocked);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taOrgAccountBlockedAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taOrgAccountBlocked/{id}", method= RequestMethod.DELETE)
    public ResponseBean taOrgAccountBlockedDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaOrgAccountBlockedService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taOrgAccountBlockedDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taOrgAccountBlocked 实体对象
     * @return
     */
    @RequestMapping(value="/taOrgAccountBlocked/{id}",method= RequestMethod.PUT)
    public ResponseBean taOrgAccountBlockedUpdate(@PathVariable Integer id,
                                        @RequestBody TaOrgAccountBlocked taOrgAccountBlocked){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaOrgAccountBlockedService.updateById(taOrgAccountBlocked)){
                responseBean.addSuccess(taOrgAccountBlocked);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taOrgAccountBlockedUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taOrgAccountBlocked/{id}",method= RequestMethod.GET)
    public ResponseBean taOrgAccountBlockedGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaOrgAccountBlockedService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taOrgAccountBlockedDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
